Index: src/gpu/gl/GrGLProgramDesc.h |
diff --git a/src/gpu/gl/GrGLProgramDesc.h b/src/gpu/gl/GrGLProgramDesc.h |
index 0584082a83fb6dbf8a2350e0a528e37c270860a2..e4db4c3581ce8a81195af0eaeee35b0fbd568fb5 100644 |
--- a/src/gpu/gl/GrGLProgramDesc.h |
+++ b/src/gpu/gl/GrGLProgramDesc.h |
@@ -42,7 +42,7 @@ public: |
* Builds a GL specific program descriptor |
* |
* @param GrPrimitiveProcessor The geometry |
* @param GrOptDrawState The optimized drawstate. The descriptor will represent a program |
* which this optstate can use to draw with. The optstate contains |
* general draw information, as well as the specific color, geometry, |
* and coverage stages which will be used to generate the GL Program for |
@@ -57,7 +57,7 @@ public: |
**/ |
static bool Build(GrProgramDesc*, |
const GrPrimitiveProcessor&, |
- const GrOptDrawState&, |
+ const GrPipeline&, |
const GrProgramDesc::DescInfo&, |
const GrGLGpu*, |
const GrBatchTracker&); |
@@ -42,7 +42,7 @@ public: |
* |
* @param GrPrimitiveProcessor The geometry |
- * @param GrOptDrawState The optimized drawstate. The descriptor will represent a program |
+ * @param GrPipeline The optimized drawstate. The descriptor will represent a program |
* which this optstate can use to draw with. The optstate contains |
* general draw information, as well as the specific color, geometry, |